==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Το πρόσθετο %1 δεν είναι συμβατό με το σύστημα.</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Προσθήκη διάταξης πληκτρολογίου</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Ημερομηνία ώρα</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>24-hour time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Ενεργοποίηση δικτύου </translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Απενεργοποίηση δικτύου</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ρυθμίσεις δικτύου </translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Είστε βέβαιος ότι θέλετε να αδειάσετε %1 αντικείμενα;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Η ενέργεια αυτή δεν είναι δυνατόν να επαναφερθεί</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Άγνωστη συσκευή</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Άγνωστος τόμος</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Δίσκος</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Αποπροσάρτηση όλων </translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Μοντέρνα λειτουργία</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Αποτελεσματική λειτουργία</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Πάνω μέρος</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Κάτω μέρος</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Εμφάνιση  </translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Απόκρυψη </translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Έξυπνη απόκρυψη </translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Λειτουργία</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Τοποθεσία</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Κατάσταση</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Πρόσθετα</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Πρόγραμμα εκκίνησης</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Ενέργεια</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ρυθμίσεις ενέργειας</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Χωρητικότητα %1, απομένουν %2 λεπτά</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Χωρητικότητα %1, απομένουν %2 ώρες και 3% λεπτά</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Φόρτιση %1, 2% λεπτά μέχρι να γεμίσει</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Φόρτιση %1, 2% ώρες και %3 λεπτά μέχρι να γεμίσει</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Πλήρη Φόρτιση</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Φορτίζεται %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Εμφάνιση Επιφάνειας Εργασίας</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Ενέργεια</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Αδρανοποίηση</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Αποσύνδεση λογαριασμού</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ρυθμίσεις ενέργειας</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Εφαρμογή</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Διακοπή σίγασης</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ήχος</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Απορρίμματα</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Κάδος απορριμμάτων - %1 αρχείο</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Κάδος απορριμμάτων - %1 αρχεία</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Κενό</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Tray Συστήματος</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <source>Unknown</source>
        <translation>Άγνωστο</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Ενσύρματη Σύνδεση: %1 </translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>No Network</source>
        <translation>Χωρίς δίκτυο  </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Συνδεδεμένο αλλά χωρίς πρόσβαση στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Ασύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Ασύρματο Δίκτυο %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.orig.tar.xz: dde-dock-5.5.38/translations/dde-dock_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Το πρόσθετο %1 δεν είναι συμβατό με το σύστημα.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Απενεργοποίηση</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Ενεργοποίηση</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ρυθμίσεις Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Απενεργοποίηση</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Ενεργοποίηση</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ρυθμίσεις Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 συνδέθηκε</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Σύνδεση...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Απενεργοποιήθηκε</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Προσθήκη διάταξης πληκτρολογίου</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Ημερομηνία ώρα</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-ωρη ώρα</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-ωρη ώρα</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ρυθμίσεις ώρας </translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Είστε βέβαιος ότι θέλετε να αδειάσετε %1 αντικείμενα;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Η ενέργεια αυτή δεν είναι δυνατόν να επαναφερθεί</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Άγνωστη συσκευή</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Άγνωστος τόμος</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Δίσκος</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Αποπροσάρτηση όλων </translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Πρόγραμμα εκκίνησης</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Έξοδος Ασφαλής Λειτουργίας</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Γραμμή Εργασιών - Ασφαλής Λειτουργία</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Η Γραμμή Εργασιών είναι σε ασφαλή λειτουργία, παρακαλώ αποχωρήστε για να εμφανιστεί σωστά</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Μοντέρνα λειτουργία</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Αποτελεσματική λειτουργία</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Πάνω μέρος</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Κάτω μέρος</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Εμφάνιση  </translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Απόκρυψη </translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Έξυπνη απόκρυψη </translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Λειτουργία</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Τοποθεσία</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Κατάσταση</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Πολλαπλές Οθόνες</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Μοντέρνα λειτουργία</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Αποτελεσματική λειτουργία</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Λειτουργία</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Πάνω μέρος</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Κάτω μέρος</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Τοποθεσία</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Κρατήστε κρυφό</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Έξυπνη απόκρυψη</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Κατάσταση</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Μικρό</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Μεγάλο</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Στην οθόνη όπου βρίσκεται ο κέρσορας</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Μόνο στην κύρια οθόνη</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Λειτουργία Multitasking</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Αφαίρεση από την γραμμή εργασιών</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Ενέργεια</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ρυθμίσεις ενέργειας</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Χωρητικότητα %1, απομένουν %2 λεπτά</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Χωρητικότητα %1, απομένουν %2 ώρες και 3% λεπτά</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Φόρτιση %1, 2% λεπτά μέχρι να γεμίσει</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Φόρτιση %1, 2% ώρες και %3 λεπτά μέχρι να γεμίσει</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Χωρητικότητα %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Φορτίζεται %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Χωρητικότητα %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Χωρητικότητα %1, πλήρης φόρτιση</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Προσθήκη στην γραμμή εργασιών</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Εμφάνιση Επιφάνειας Εργασίας</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Αφαίρεση από την γραμμή εργασιών</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Ενέργεια</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Αδρανοποίηση</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Αποσύνδεση λογαριασμού</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ρυθμίσεις ενέργειας</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Διακοπή σίγασης</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Σίγαση</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ρυθμίσεις ήχου</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Ένταση %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ήχος</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Απορρίμματα</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Κάδος απορριμμάτων - %1 αρχείο</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Κάδος απορριμμάτων - %1 αρχεία</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Μετακίνηση στα Απορρίμματα</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Κενό</translation>
    </message>
</context>
</TS>
